/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2016 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.dds.projects.sxa.integrationtest;

import org.apache.log4j.Level;
import org.apache.log4j.Logger;
import org.junit.BeforeClass;
import org.junit.Ignore;
import org.junit.Test;

import dk.nsi.dds.projects.sxa.testhelper.SxaLoggerHelper;
import dk.nsi.dds.projects.sxa.testhelper.SxaQueryHelper;
import dk.nsi.dds.projects.sxa.testhelper.SxaTestDataHelper;
import dk.nsi.dds.projects.sxa.testhelper.ddsinvoker.DDSInvokerHelper;
import dk.nsi.documentsharing.consumer.DocumentConsumer;
import dk.nsi.documentsharing.core.query.DocumentMetadataQueryResult;
import dk.nsi.documentsharing.core.retrieve.RetrievedDocumentsResult;
import dk.nsi.documentsharing.testutil.DocumentSharingTestUtil;
import junit.framework.Assert;

/**
 * These tests assume that SXA configuration is altered in order to verify error behavior.
 * As manual re-configuration is required, they have been set to ignored.
 */
@Ignore
public class SxaConfigurationChangeIT {

  private static final Logger logger = Logger.getLogger(SxaConfigurationChangeIT.class);
  private DocumentSharingTestUtil testutil = new DocumentSharingTestUtil();

  private static DocumentConsumer docConsumer; 
  private static SxaQueryHelper queryHelper;

  @BeforeClass
  public static void setupClass() throws Exception {
    SxaLoggerHelper.setupLogger(Level.INFO); // Set to Level.DEBUG to print out queries, returned metadata etc.
    docConsumer = DDSInvokerHelper.getConsumer();
    queryHelper = new SxaQueryHelper(docConsumer, new SxaTestDataHelper());
  }

  /**
   * Verifies that a query:
   * - using query parameters designating SXA-data
   * and subsequent document retrieval results in no SXA document
   * and an error stating that the SXA repository is busy
   * when the backend service has too short timeout on invoking it service
   */
  @Ignore("Prerequisite is setting backend service timeout to 1 second")
  @Test
  public void busyErrorOnRetrieveSxaDocumentWithTimedoutBackendService() throws Exception {
    // Arrange
    DocumentMetadataQueryResult queryResult = docConsumer.doQuery(queryHelper.prepareQueryForSxaData());
    // Act
    RetrievedDocumentsResult retrievedDocuments = docConsumer.doRetrieve(docConsumer.prepareRetrieve(queryResult.getDocumentMetadataList()));
    logger.debug(testutil.prettyPrint(retrievedDocuments));
    // Assert
    Assert.assertFalse(retrievedDocuments.hasResult());
    Assert.assertTrue(retrievedDocuments.getUnreachableDocuments().size() > 0);
    Assert.assertTrue(retrievedDocuments.getDocumentSharingErrorList().hasErrors());
    Assert.assertTrue(retrievedDocuments.getDocumentSharingErrorList().getErrors().get(0).getErrorCode().contains("Busy"));
  }

  /**
   * Verifies that a query:
   * - using query parameters designating Sxa-data
   * and subsequent document retrieval results in no SXA document
   * and an error stating that the document to retrieve is unavailable
   * when the LabInvoker is configured to invoke non-existing service
   */
  @Ignore("Prerequisite is setting Backend Service endpoint to bogus")
  @Test
  public void unreachableErrorOnRetrieveSxaDocumentWithBogusBackendServiceEndpoint() throws Exception {
    // Arrange
    DocumentMetadataQueryResult queryResult = docConsumer.doQuery(queryHelper.prepareQueryForSxaData());
    // Act
    RetrievedDocumentsResult retrievedDocuments = docConsumer.doRetrieve(docConsumer.prepareRetrieve(queryResult.getDocumentMetadataList()));
    logger.debug(testutil.prettyPrint(retrievedDocuments));
    // Assert
    Assert.assertFalse(retrievedDocuments.hasResult());
    Assert.assertTrue(retrievedDocuments.getUnreachableDocuments().size() > 0);
    Assert.assertTrue(retrievedDocuments.getDocumentSharingErrorList().hasErrors());
    Assert.assertTrue(retrievedDocuments.getDocumentSharingErrorList().getErrors().get(0).getErrorCode().contains("Unavailable"));
  }

}
