/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2016 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.dds.projects.sxa.integrationtest;

import org.junit.BeforeClass;
import org.junit.Test;

import dk.nsi.dds.projects.sxa.testhelper.SxaQueryHelper;
import dk.nsi.dds.projects.sxa.testhelper.SxaTestDataHelper;
import dk.nsi.dds.projects.sxa.testhelper.ddsinvoker.DDSInvokerHelper;
import dk.nsi.documentsharing.consumer.DocumentConsumer;
import dk.nsi.documentsharing.core.query.DocumentMetadataQueryResult;
import dk.nsi.documentsharing.core.query.FindDocumentsQuery;
import junit.framework.Assert;

/**
 * Tests of SXA documentsharing not affected by presence of other document metadata providers or
 * registered document metadata. 
 */

public class SxaErrorsIT {

  private static DocumentConsumer docConsumer; 
  private static SxaQueryHelper queryHelper;
  private static SxaTestDataHelper testDataHelper;
  
  @BeforeClass
  public static void setupClass() throws Exception {
    docConsumer = DDSInvokerHelper.getConsumer();
    testDataHelper = new SxaTestDataHelper();
    queryHelper = new SxaQueryHelper(docConsumer, testDataHelper);
  }

  @Test
  public void noMetadataReturnedForPatientIdContainingAlphanum() throws Exception {
    // Arrange
    FindDocumentsQuery query = queryHelper.prepareQueryForSxaData(testDataHelper.getIllegalPatientId());
    // Act
    DocumentMetadataQueryResult queryResult = docConsumer.doQuery(query);
    // Assert
    Assert.assertNotNull(queryResult);
    Assert.assertTrue(queryResult.hasResult());
    Assert.assertEquals(0, queryResult.getDocumentMetadataList().size());
    Assert.assertFalse(queryResult.isStatusFailed());
  }

}
