/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2016 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.dds.projects.sxa.testhelper;

import java.io.StringReader;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;
import java.util.List;
import java.util.Set;
import java.util.function.Function;
import java.util.stream.Collectors;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathFactory;

import org.bouncycastle.util.encoders.Base64;
import org.joda.time.Interval;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;

import dk.nsi.documentsharing.consent.helper.Consent;
import dk.nsi.documentsharing.consent.helper.ConsentHelper;
import dk.nsi.documentsharing.core.retrieve.RetrievedDocument;
import dk.nsi.documentsharing.core.retrieve.RetrievedDocumentsResult;

public class SxaConsentHelper {
  private ConsentHelper consentHelper;
  
  private static final String XSTRING = "/*[local-name()='LaboratoryReport']/*[local-name()='Receiver']/*[local-name()='Identifier']";
  
  public SxaConsentHelper(ConsentHelper consentHelper) {
    super();
    this.consentHelper = consentHelper;
  }
  
  
  public void ensureNegativeConsentForPatientAgainstInformationFrom(String patientId, String organisationIdBySor) throws Exception {
    consentHelper.revokeAllConsents(patientId);
    
    Calendar cal = Calendar.getInstance();
    cal.set(1975, 1, 1);   
    Date startDate = cal.getTime();
    cal.set(2039, 1, 1);
    Date endDate = cal.getTime();
  
    consentHelper.ensureNegativeDataspecificConsentIsActive(patientId, organisationIdBySor, startDate, endDate);
  }
  
  public int getNumberOfDocuments(RetrievedDocumentsResult retrievedDocumentsResult) {
    
    byte[] document = retrievedDocumentsResult.getDocuments().get(0).getDocument();
    try {
      List<String> rawDocuments = getDocumentsArrayFromRetrievedDocument(document, "/ResultatPakkePIH/RaaSvar/LeverandoerSvar/LeverandoerSvarXml/DocumentWrapper");
      return rawDocuments.size();
    } catch (Exception e) {
      e.printStackTrace();
    }
    return -1;
  }
  
  
  private List<String> getDocumentsArrayFromRetrievedDocument(byte[] document, String xString) throws Exception {
    List<String> resultArray = new ArrayList<String>();
    
    String xml = new String(document, "utf-8");
    String trimmedXml = xml.trim().replaceFirst("^([\\W]+)<","<");
    
    DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
    DocumentBuilder builder = factory.newDocumentBuilder();
    Document doc = builder.parse(new InputSource(new StringReader(trimmedXml)));
    XPathFactory xPathfactory = XPathFactory.newInstance();
    XPath xpath = xPathfactory.newXPath();
    XPathExpression expr = xpath.compile(xString);
    NodeList nodeList = (NodeList) expr.evaluate(doc, XPathConstants.NODESET);
    
    for (int i = 0; i < nodeList.getLength(); i++) {
      Node node = nodeList.item(i);
      resultArray.add(node.getFirstChild().getNodeValue());
    }
    return resultArray;
  }
  
  public void revokeAllConsents(final String patientId) throws Exception {
    consentHelper.revokeAllConsents(patientId);
  }
}

