/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2016 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.dds.projects.sxa.testhelper.ddsinvoker;

import dk.nsi.documentsharing.consumer.DocumentConsumer;
import dk.nsi.documentsharing.docsharingservices.ConfigurationProvider;
import dk.nsi.documentsharing.docsharingservices.DSSDocumentConsumerFactory;
import dk.nsi.documentsharing.docsharingservices.DSSSystemContextProviderSample;
import dk.nsi.documentsharing.docsharingservices.DSSUserContextProviderDGWSSample;
import dk.nsi.documentsharing.docsharingservices.FileBasedConfigurationProvider;
import dk.nsi.documentsharing.docsharingservices.context.DSSInvocationContextProvider;
import dk.nsi.documentsharing.docsharingservices.context.impl.DSSInvocationContextProviderImpl;

public class DDSInvokerHelper {
  private static ConfigurationProvider config = new FileBasedConfigurationProvider(System.getProperty("testclient.properties"));
  private static DSSInvocationContextProvider contextProvider = null;
  private static DSSCitizenInvocationContextProvider citizenContextProvider = null;
  private static DSSCitizenUserContextProvider citizenUserContextProvider = null;
  
  public static ConfigurationProvider getConfig() {
    return config;
  }

  public static DSSInvocationContextProvider getInvocationContextProvider() throws Exception {
    if (contextProvider == null) {
        contextProvider = new DSSInvocationContextProviderImpl(new DSSSystemContextProviderSample(config), new DSSUserContextProviderDGWSSample(config));
    }
    return contextProvider;
  }

  public static DocumentConsumer getConsumer() throws Exception {
    DSSDocumentConsumerFactory dssDocConsumerFactory = new DSSDocumentConsumerFactory(getInvocationContextProvider());
    DocumentConsumer docConsumer = dssDocConsumerFactory.getInstance();
    return docConsumer;
  }

  ///
  /// Citizen versions
  ///

  public static DSSCitizenInvocationContextProvider getCitizenInvocationContextProvider() throws Exception {
    if (citizenContextProvider == null) {
      citizenContextProvider = new DSSCitizenInvocationContextProviderImpl(new DSSSystemContextProviderSample(config), citizenUserContextProvider);
    }
    return citizenContextProvider;
  }
  
  public static void resetCitizenInvocationContextProvider() {
    citizenContextProvider = null;
  }
  
  public static DocumentConsumer getCitizenConsumer(String userId) throws Exception {
    citizenUserContextProvider = new DSSCitizenUserContextProviderDGWSSample(config, userId);
    DSSDocumentConsumerFactory dssDocConsumerFactory = new DSSDocumentConsumerFactory(getCitizenInvocationContextProvider());
    DocumentConsumer docConsumer = dssDocConsumerFactory.getInstance();
    return docConsumer;
  }

}
