/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2016 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.dds.projects.sxa.testhelper.ddsinvoker;

import java.io.File;
import java.util.Properties;

import dk.nsi.documentsharing.docsharingservices.ConfigurationProvider;
import dk.nsi.documentsharing.docsharingservices.ConfigurationProvider.ConfigurationKey;
import dk.nsi.documentsharing.docsharingservices.security.SignedUserIdCardProvider;
import dk.sosi.seal.model.IDCard;
import dk.sosi.seal.model.SignatureUtil;
import dk.sosi.seal.pki.CredentialVaultSignatureProvider;
import dk.sosi.seal.vault.CredentialVault;
import dk.sosi.seal.vault.FileBasedCredentialVault;

public class DSSCitizenUserContextProviderDGWSSample implements DSSCitizenUserContextProvider {

  private ConfigurationProvider config;
  private IDCard idCard;
  private String userId;

  public DSSCitizenUserContextProviderDGWSSample(ConfigurationProvider config) throws Exception {
    this(config, null);
  }

  public DSSCitizenUserContextProviderDGWSSample(ConfigurationProvider config, String userId)
      throws Exception {
    this.config = config;
    this.userId = userId;
  }

  public IDCard getIDCard() throws Exception {
    if (idCard == null || !idCard.isValidInTime()) {
      File keyStoreFile = new File(config.getProperty(ConfigurationKey.user_testcertificate_keystore_filepath));
      if (keyStoreFile == null || !keyStoreFile.exists()) {
        throw new IllegalStateException("No keystore file: " + keyStoreFile != null ? keyStoreFile.getAbsolutePath() : null);
      }
      SignedUserIdCardProvider signedUserIdCardProvider = 
          new SignedUserIdCardProvider(config.getProperty(ConfigurationKey.sts_service_endpoint),
            config.getBooleanProperty(ConfigurationKey.sts_test_mode));
      Properties properties = SignatureUtil.setupCryptoProviderForJVM();
      CredentialVault vault = new FileBasedCredentialVault(
        properties,
        keyStoreFile, 
        config.getProperty(ConfigurationKey.user_testcertificate_keystore_password));
      CredentialVaultSignatureProvider signatureProvider = new CredentialVaultSignatureProvider(vault, properties);
      idCard = signedUserIdCardProvider.getUserIdCardSignedBySts(
        signatureProvider,
        config.getProperty(ConfigurationKey.user_name),
        config.getProperty(ConfigurationKey.user_surname),
        config.getProperty(ConfigurationKey.user_email),
        config.getProperty(ConfigurationKey.user_role),
        config.getProperty(ConfigurationKey.user_education_code),
        config.getProperty(ConfigurationKey.user_authorization_number),
        config.getProperty(ConfigurationKey.user_testcertificate_cvr_number),
        config.getProperty(ConfigurationKey.user_testcertificate_organisation_name),
        config.getProperty(ConfigurationKey.system_name)
          );
    }
    return idCard;
  }

  @Override
  public String getUserId() {
    return userId;
  }

}
