/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2012 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsi.dds.projects.sxa.labreportservicestub.configuration;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.Charset;
import java.nio.file.Files;
import java.util.Properties;

import org.apache.log4j.Logger;

public class SxaPropertyReader {
  private static Logger logger = Logger.getLogger(SxaPropertyReader.class);
  private Properties properties;

  public SxaPropertyReader(File propertyFile) throws IOException {
      properties = new Properties();
      loadResource(propertyFile);
  }

  public SxaPropertyReader(InputStream is) throws IOException {
    properties = new Properties();
    if (is != null) {
      properties.load(is);
    }
  }

  protected void loadResource(File propertyFile) throws IOException {
      Properties tempProperties = null;
      if (!propertyFile.exists()) {
          logger.error("Propertyfile ["+propertyFile.getPath()+"] does not exist");
      }
      try (BufferedReader reader = Files.newBufferedReader(propertyFile.toPath(), Charset.forName("UTF-8"))) {
          tempProperties = new Properties();
          tempProperties.load(reader);
          this.properties = tempProperties;
      }
  }

  public String get(String property) {
      return properties.getProperty(property); 
  }
}
