/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2016 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.dds.projects.sxa.documentmetadataprovider;

import dk.nsi.documentsharing.core.query.DocumentMetadataQueryResult;
import dk.nsi.documentsharing.core.query.FindDocumentsQuery;
import dk.nsi.documentsharing.metadataprovider.DocumentMetadataProvider;
import dk.nsi.documentsharing.metadataprovider.impl.MetadataProviderQuery;
import dk.nsi.documentsharing.metadataprovider.impl.MetadataProviderQueryImpl;
import dk.nsi.documentsharing.xds.UnexpectedDataException;
import dk.nsi.documentsharing.xds.UnexpectedEncodingException;
import dk.nsi.documentsharing.xds.impl.AdhocQueryRequestBuilder;
import dk.nsi.documentsharing.xds.impl.AdhocQueryResponseParser;
import dk.nsi.documentsharing.xds.impl.StrictnessDeciderImpl;
import oasis.names.tc.ebxml_regrep.xsd.query._3.AdhocQueryRequest;
import oasis.names.tc.ebxml_regrep.xsd.query._3.AdhocQueryResponse;

public class DocumentMetadataProviderHelper {

  public DocumentMetadataQueryResult doRequest(FindDocumentsQuery query, DocumentMetadataProvider documentMetadataProvider)
        throws UnexpectedDataException, UnexpectedEncodingException {

    AdhocQueryRequestBuilder builder = new AdhocQueryRequestBuilder();
    MetadataProviderQuery metadataProviderQuery = new MetadataProviderQueryImpl(documentMetadataProvider);

    AdhocQueryRequest request = builder.createRegistryStoredQueryFindDocumentsRequest(query);
    AdhocQueryResponse response = metadataProviderQuery.handleRequest(request);

    AdhocQueryResponseParser parser = new AdhocQueryResponseParser(new StrictnessDeciderImpl(true));
    DocumentMetadataQueryResult metadataResult = parser.parseAsDocumentMetadataQueryResult(response);

    return metadataResult;
  }
}