/**
 * The MIT License
 *
 * Original work sponsored and donated by National Board of e-Health (NSI), Denmark
 * (http://www.nsi.dk)
 *
 * Copyright (C) 2016 National Board of e-Health (NSI), Denmark (http://www.nsi.dk)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsi.dds.projects.sxa.documentprovider.impl;

import java.io.File;
import java.util.EnumSet;

import dk.nsi.documentsharing.util.configloading.JbossConfigFileFinder;
import dk.nsi.util.Config;

public class SXADocumentProviderConfig extends Config {
  private static final String SXA_PROPERTY_FILE_NAME = "SXADocumentProvider.properties";
  private static final File SXA_PROPERTY_FILE = JbossConfigFileFinder
    .loadConfigFromJboss(SXA_PROPERTY_FILE_NAME);

  public enum SXAConfigKeys {
    REQUEST_TIMEOUT_SECONDS("sxa.labservice.request.timeout.seconds"), 
    ENDPOINT_URL("sxa.labservice.endpoint"), 
    WSDL_URL("sxa.labservice.wsdl"), 
    ROOT_ID("sxa.document.unique.root.id"), 
    USERNAME("sxa.labservice.request.username"), 
    PASSWORD("sxa.labservice.request.password"),
    SAMTYKKE_KODE("sxa.labservice.request.samtykkekode"),
    SAMTYKKE_TEKST("sxa.labservice.request.samtykketekst"),
    SLUTBRUGER_IDENTIFIKATION("sxa.labservice.request.slutbruger.identifikation"),
    SLUTBRUGER_ORGANISATION("sxa.labservice.request.slutbruger.organisation"),
    SLUTBRUGER_CPR("sxa.labservice.request.slutbruger.cpr"),
    SLUTBRUGER_FORNAVN("sxa.labservice.request.slutbruger.fornavn"),
    SLUTBRUGER_EFTERNAVN("sxa.labservice.request.slutbruger.efternavn"),
    SLUTBRUGER_STILLING("sxa.labservice.request.slutbruger.stilling"),
    SLUTBRUGER_EMAIL("sxa.labservice.request.slutbruger.email"),
    SLUTBRUGER_ROLLE("sxa.labservice.request.slutbruger.rolle"),
    SLUTBRUGER_AUTORISATIONSKODE("sxa.labservice.request.slutbruger.autorisationskode"),
    SXA_SERVICECHECK_FAILURE_THRESHOLD("sxa.labservice.servicecheck.failurethreshold");
    
    private String key;

    private SXAConfigKeys(String key) {
      this.key = key;
    }

    public String toString() {
      return key;
    }
  }

  public SXADocumentProviderConfig(String name) {
    super();
    this.name = name;
    addRequiredKeys(EnumSet.allOf(SXAConfigKeys.class));
  }

  @Override
  public File getConfigFile() {
    return SXA_PROPERTY_FILE;
  }
}
